@@ -27,23 +27,6 @@ class ErrorsAsJsonApi:
             self.init_app(app)
 
     def init_app(self, app: flask.Flask):
-        # Do we need this?
-        # @app.after_request
-        # def add_id_to_errors(response):
-        #     if 400 <= response.status_code < 600 and response.is_json:
-        #         data = response.json
-        #         if (
-        #             "errors" in data
-        #             and len(data["errors"]) > 0
-        #             and "id" not in data["errors"][0]
-        #         ):
-        #             data["errors"][0]["id"] = request_id()
-        #             status_code = response.status_code
-        #             response = flask.jsonify(data)
-        #             response.status_code = status_code
-
-        #     return response
-
         self.register(Exception, app=app)
         for http_status in default_exceptions:
             self.register(http_status, app=app)
@@ -73,11 +56,22 @@ class ErrorsAsJsonApi:
 
     @classmethod
     def _std_handler(cls, error):
-        logger.error(
-            "Exception bubbled to top level handler and was returned as HTTP "
-            "JSON response.",
-            exc_info=True,
-        )
+        if error in {401, 403, 405} or isinstance(
+            error,
+            (default_exceptions[401], default_exceptions[403], default_exceptions[405]),
+        ):
+            logger.debug(
+                "Exception bubbled to top level handler and was returned as HTTP "
+                "JSON response.",
+                exc_info=True,
+            )
+        else:
+            logger.error(
+                "Exception bubbled to top level handler and was returned as HTTP "
+                "JSON response.",
+                exc_info=True,
+            )
+
         return error_response_from(
             error,
             getattr(getattr(flask, "g", None), "request_id", ""),
